@@ -7,22 +7,23 @@
 # see:
 # - perl5
 
-use 5.010;
+use v5.10;
 package perl5::ingy;
 
-use perl5 0.04;
+use perl5 0.06 ();
+use base 'perl5';
 
-our $VERSION = '0.05';
-our @ISA = qw[perl5];
+our $VERSION = '0.06';
 
-sub code {
-    return <<'...';
-use IO::All 0.41;
-use YAML::XS 0.35;
-use Capture::Tiny 0.11 ':all';
-use XXX 0.17 -with => 'YAML::XS';
-...
-}
+use constant imports => (
+    strict =>
+    warnings =>
+    feature => [':5.10'],
+    'IO::All' => 0.41,
+    'YAML::XS' => 0.35,
+    'Capture::Tiny' => 0.11, [':all'],
+    XXX => 0.17, [-with => 'YAML::XS'],
+);
 
 1;
 
@@ -40,7 +41,7 @@ Using this module is the same as:
     use IO::All;
     use YAML::XS;
     use Capture::Tiny ':all';
-    use XXX -with => 'YAML::XS';
+    ;use XXX -with => 'YAML::XS';
 
 This is an early release. More modules will be added as this framework
 matures.
@@ -48,5 +49,5 @@ matures.
 =head1 STATUS
 
 This module is brand new. Don't use it. I wouldn't if I were you. But I'm not
-you. I use it. But I'm Ingy. This module is name after me. You are not Ingy.
+you. I use it. But I'm Ingy. This module is named after me. You are not Ingy.
 This module is not named after you. iykwimaittydrotflmaowtfbbqstfuftwkthxbai.
